package WebDP::Quiz::Session::Paranoid;
use strict;
use base qw(WebDP::Quiz::Session);

use Digest::MD5 qw(md5_hex);

sub open {
    my $class = shift;
    my %cookie = CGI::Cookie->fetch;

    # no cookie, return undef
    return unless exists $cookie{sid};

    my %cook = $cookie{sid}->value;
    my $self = bless {}, $class;

    $self->_check_paranoid(\%cook);
    $self->load($cook{sid});
    return $self;
}

sub generate_cookie {
    my $self = shift;
    return CGI::Cookie->new(
	-name => 'sid',
	-value => {
	    sid => $self->id,
	    digest => $self->_digest($self->id), # 1
	},
    );
}

sub _check_paranoid {
    my($self, $cook) = @_;
    my $digest = $self->_digest($cook->{sid});
    if ($digest ne $cook->{digest}) {
	die "paranoid check failed: $digest != $cook->{digest}"; # 3
    }
}

sub _digest {
    my($self, $sid) = @_;
    return md5_hex($sid . $ENV{REMOTE_HOST} . $ENV{HTTP_USER_AGENT} . '_secret_string_'); # 2
}

1;
