#!/usr/local/bin/perl -Tw

use strict;
use CGI;
use WebDP::Quiz::Session;
use WebDP::Quiz::Questions;

my $query   = CGI->new;
my $session = WebDP::Quiz::Session->open or die "no session";

my $answer = $query->param('answer');
if (defined $answer) {
    store_answer($query, $session, $answer);
    $session->set(current_idx => $session->get('current_idx') + 1);
}

my $idx  = $session->get('current_idx') || 0;
my $quiz = WebDP::Quiz::Questions->get_quiz($idx);

if (! $quiz) {
    (my $url = $query->url) =~ s/main\.cgi/result.cgi/;
    print $query->redirect($url);
}
else {
    display_form($query, $session, $quiz);
}

sub store_answer {
    my($query, $session, $answer) = @_;
    my $answers = $session->get('answers') || [];
    push @{$answers}, $answer;
    $session->set(answers => $answers);
}

sub display_form {
    my($query, $session, $quiz) = @_;

    my $question    = $quiz->{question};
    my @alternative = @{$quiz->{alternative}};
    my $alt_group   = $query->radio_group(
	-name => 'answer',
	-values => [ 0..$#alternative ],
	-labels => { map { $_ => $alternative[$_] } 0..$#alternative },
	-override => 1,
    );
    print $query->header(
	-type => 'text/html; charset=euc-jp',
	-cache_control => 'no-cache',
    ), <<"__HTML__";
<HTML>
<BODY>
Question: $question<BR>

<FORM action="./main.cgi" method="POST">
$alt_group<BR>
<INPUT type="submit" value=" Answer ">
</FORM>

<P>
<A href="./entry.cgi">RESTART</A>
</BODY>
</HTML>
__HTML__
}
